@@ -63,6 +63,7 @@ def shape(a: Numeric):  # pragma: no cover
 
     Args:
         a (tensor): Tensor.
+        *dims (int, optional): Dimensions to get.
 
     Returns:
         object: Shape of `a`.
@@ -82,6 +83,21 @@ def shape(a: Union[list, tuple]):
     return np.array(a).shape
 
 
+@dispatch
+def shape(a, dim: Int):
+    return B.shape(a)[dim]
+
+
+@dispatch
+def shape(a, *dims: Int):
+    a_shape = B.shape(a)
+    subshape = tuple(a_shape[i] for i in dims)
+    if LazyShapes.enabled:
+        return Shape(*subshape)
+    else:
+        return subshape
+
+
 @dispatch
 def rank(a: Union[Numeric, list, tuple]):  # pragma: no cover
     """Get the shape of a tensor.
